@@ -1,7 +1,7 @@
 from contextlib import contextmanager
 import sys
 
-from six import StringIO
+from io import StringIO
 
 
 @contextmanager
